@@ -4,12 +4,14 @@
 #include "state.hpp"
 #include "trainer.hpp"
 
+#include "unsupported/Eigen/src/SpecialFunctions/SpecialFunctionsImpl.h"
 #include "util.hpp"
 #include <Eigen/Core>
 #include <Eigen/Sparse>
 #include <algorithm>
 #include <cmath>
 #include <cstdint>
+#include <future>
 #include <pybind11/eigen.h>
 #include <pybind11/pybind11.h>
 #include <pybind11/stl.h>
@@ -207,13 +209,11 @@ Real log_likelihood_doc_topic(const Eigen::Ref<RealVector> &doc_topic_prior,
   Real ll = n_doc * (std::lgamma(doc_topic_prior.sum()) -
                      doc_topic_prior.array().lgamma().sum());
   Real doc_topic_sum = doc_topic_prior.array().sum();
-
   ll += (doc_topic.array().cast<Real>().rowwise() +
          doc_topic_prior.transpose().array())
             .lgamma()
             .sum();
   ll -= (doc_length.array().cast<Real>() + doc_topic_sum).lgamma().sum();
-
   return ll;
 }
 
